@@ -39,8 +39,6 @@
 #include <gedit/gedit-utils.h>
 #include <gedit/gedit-window.h>
 
-#include <gedit/gseal-gtk-compat.h>
-
 /* Properties */
 enum 
 {
@@ -204,7 +202,6 @@ gedit_close_confirmation_dialog_init (GeditCloseConfirmationDialog *dlg)
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 			     14);
 	gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
 	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dlg), TRUE);
 	
 	gtk_window_set_title (GTK_WINDOW (dlg), "");
