@@ -67,6 +67,7 @@ typedef struct
 
 struct _GeditMessageType
 {
+	/* FIXME this is an issue for introspection */
 	gint ref_count;
 
 	gchar *object_path;
@@ -78,6 +79,10 @@ struct _GeditMessageType
 	GHashTable *arguments; /* mapping of key -> ArgumentInfo */
 };
 
+G_DEFINE_BOXED_TYPE (GeditMessageType, gedit_message_type,
+                     gedit_message_type_ref,
+                     gedit_message_type_unref)
+
 /**
  * gedit_message_type_ref:
  * @message_type: the #GeditMessageType
@@ -119,32 +124,10 @@ gedit_message_type_unref (GeditMessageType *message_type)
 	g_free (message_type);
 }
 
-/**
- * gedit_message_type_get_type:
- * 
- * Retrieves the GType object which is associated with the
- * #GeditMessageType class.
- * 
- * Return value: the GType associated with #GeditMessageType.
- **/
-GType 
-gedit_message_type_get_type (void)
-{
-	static GType our_type = 0;
-
-	if (!our_type)
-		our_type = g_boxed_type_register_static (
-			"GeditMessageType",
-			(GBoxedCopyFunc) gedit_message_type_ref,
-			(GBoxedFreeFunc) gedit_message_type_unref);
-
-	return our_type;
-}
-
 /**
  * gedit_message_type_identifier:
- * @object_path: the object path
- * @method: the method
+ * @object_path: (allow-none): the object path
+ * @method: (allow-none): the method
  *
  * Get the string identifier for @method at @object_path.
  *
@@ -160,7 +143,7 @@ gedit_message_type_identifier (const gchar *object_path,
 
 /**
  * gedit_message_type_is_valid_object_path:
- * @object_path: the object path
+ * @object_path: (allow-none): the object path
  *
  * Returns whether @object_path is a valid object path
  *
@@ -248,8 +231,8 @@ gedit_message_type_is_supported (GType type)
 
 /**
  * gedit_message_type_new_valist:
- * @object_path: the object path
- * @method: the method
+ * @object_path: (allow-none): the object path
+ * @method: (allow-none): the method
  * @num_optional: number of optional arguments
  * @var_args: key/gtype pair variable argument list
  *
@@ -289,8 +272,8 @@ gedit_message_type_new_valist (const gchar *object_path,
 
 /**
  * gedit_message_type_new:
- * @object_path: the object path
- * @method: the method
+ * @object_path: (allow-none): the object path
+ * @method: (allow-none): the method
  * @num_optional: number of optional arguments
  * @...: key/gtype pair variable argument list
  *
@@ -421,7 +404,7 @@ gedit_message_type_set_valist (GeditMessageType *message_type,
  * Instantiate a new message from the message type with specific values
  * for the message arguments.
  *
- * Return value: the newly created message
+ * Return value: (transfer full): the newly created message
  *
  */
 GeditMessage *
@@ -446,7 +429,7 @@ gedit_message_type_instantiate_valist (GeditMessageType *message_type,
  * Instantiate a new message from the message type with specific values
  * for the message arguments.
  *
- * Return value: the newly created message
+ * Return value: (transfer full): the newly created message
  *
  */
 GeditMessage *
@@ -540,7 +523,7 @@ foreach_gtype (const gchar  *key,
 /**
  * gedit_message_type_foreach:
  * @message_type: the #GeditMessageType
- * @func: the callback function
+ * @func: (scope call): the callback function
  * @user_data: user data supplied to the callback function
  *
  * Calls @func for each argument in the message type.
