@@ -23,7 +23,6 @@
 #include "gedit-status-combo-box.h"
 
 #include <gdk/gdkkeysyms.h>
-#include "gseal-gtk-compat.h"
 
 #define COMBO_BOX_TEXT_DATA "GeditStatusComboBoxTextData"
 
@@ -179,8 +178,9 @@ menu_position_func (GtkMenu		*menu,
 	GtkAllocation allocation;
 	
 	*push_in = FALSE;
-	
-	gtk_widget_size_request (gtk_widget_get_toplevel (GTK_WIDGET (menu)), &request);
+
+	gtk_widget_get_preferred_size (gtk_widget_get_toplevel (GTK_WIDGET (menu)),
+	                               &request, NULL);
 	
 	/* get the origin... */
 	gdk_window_get_origin (gtk_widget_get_window (GTK_WIDGET (combo)), x, y);
@@ -204,8 +204,9 @@ show_menu (GeditStatusComboBox *combo,
 	GtkRequisition request;
 	gint max_height;
 	GtkAllocation allocation;
-	
-	gtk_widget_size_request (combo->priv->menu, &request);
+
+	gtk_widget_get_preferred_size (combo->priv->menu,
+	                               &request, NULL);
 
 	/* do something relative to our own height here, maybe we can do better */
 	gtk_widget_get_allocation (GTK_WIDGET (combo), &allocation);
@@ -253,9 +254,9 @@ key_press_event (GtkWidget           *widget,
 		 GdkEventKey         *event,
 		 GeditStatusComboBox *combo)
 {
-	if (event->keyval == GDK_Return || event->keyval == GDK_ISO_Enter ||
-	    event->keyval == GDK_KP_Enter || event->keyval == GDK_space ||
-	    event->keyval == GDK_KP_Space)
+	if (event->keyval == GDK_KEY_Return || event->keyval == GDK_KEY_ISO_Enter ||
+	    event->keyval == GDK_KEY_KP_Enter || event->keyval == GDK_KEY_space ||
+	    event->keyval == GDK_KEY_KP_Space)
 	{
 		show_menu (combo, 0, event->time);
 		return TRUE;
@@ -344,12 +345,22 @@ gedit_status_combo_box_init (GeditStatusComboBox *self)
 }
 
 /* public functions */
+
+/**
+ * gedit_status_combo_box_new:
+ * @label: (allow-none):
+ */
 GtkWidget *
 gedit_status_combo_box_new (const gchar *label)
 {
 	return g_object_new (GEDIT_TYPE_STATUS_COMBO_BOX, "label", label, NULL);
 }
 
+/**
+ * gedit_status_combo_box_set_label:
+ * @combo:
+ * @label: (allow-none):
+ */
 void
 gedit_status_combo_box_set_label (GeditStatusComboBox *combo, 
 				  const gchar         *label)
@@ -378,6 +389,12 @@ item_activated (GtkMenuItem         *item,
 	gedit_status_combo_box_set_item (combo, item);
 }
 
+/**
+ * gedit_status_combo_box_add_item:
+ * @combo:
+ * @item:
+ * @text: (allow-none):
+ */
 void
 gedit_status_combo_box_add_item (GeditStatusComboBox *combo,
 				 GtkMenuItem         *item,
@@ -403,6 +420,12 @@ gedit_status_combo_box_remove_item (GeditStatusComboBox *combo,
 			      GTK_WIDGET (item));
 }
 
+/**
+ * gedit_status_combo_box_get_items:
+ * @combo:
+ *
+ * Returns: (element-type Gtk.Widget) (transfer container):
+ */
 GList *
 gedit_status_combo_box_get_items (GeditStatusComboBox *combo)
 {
@@ -425,6 +448,12 @@ gedit_status_combo_box_get_item_text (GeditStatusComboBox *combo,
 	return ret;
 }
 
+/**
+ * gedit_status_combo_box_set_item_text:
+ * @combo:
+ * @item:
+ * @text: (allow-none):
+ */
 void 
 gedit_status_combo_box_set_item_text (GeditStatusComboBox *combo,
 				      GtkMenuItem	  *item,
