@@ -77,14 +77,17 @@ struct _GeditViewClass
 
 	/* Key bindings */
 	gboolean (* start_interactive_search)	(GeditView       *view);
-	gboolean (* start_interactive_goto_line)(GeditView       *view);	
+	gboolean (* start_interactive_goto_line)(GeditView       *view);
 	gboolean (* reset_searched_text)	(GeditView       *view);
+
+	void	 (* drop_uris)			(GeditView	 *view,
+						 gchar          **uri_list);
 };
 
 /*
  * Public methods
  */
-GtkType		 gedit_view_get_type     	(void) G_GNUC_CONST;
+GType		 gedit_view_get_type     	(void) G_GNUC_CONST;
 
 GtkWidget	*gedit_view_new			(GeditDocument   *doc);
 
@@ -96,13 +99,6 @@ void		 gedit_view_select_all		(GeditView       *view);
 
 void		 gedit_view_scroll_to_cursor 	(GeditView       *view);
 
-void 		 gedit_view_set_colors 		(GeditView       *view, 
-						 gboolean         def,
-						 GdkColor        *backgroud, 
-						 GdkColor        *text,
-						 GdkColor        *selection, 
-						 GdkColor        *sel_text);
-
 void 		 gedit_view_set_font		(GeditView       *view,
 						 gboolean         def,
 						 const gchar     *font_name);
@@ -110,3 +106,5 @@ void 		 gedit_view_set_font		(GeditView       *view,
 G_END_DECLS
 
 #endif /* __GEDIT_VIEW_H__ */
+
+/* ex:ts=8:noet: */
