@@ -43,7 +43,6 @@
 #include "gedit-app.h"
 #include "gedit-encodings.h"
 
-#include "gseal-gtk-compat.h"
 #include "gedit-commands.h"
 #include "gedit-debug.h"
 #include "gedit-dirs.h"
@@ -164,14 +163,13 @@ gedit_main (gboolean service)
 	GeditPluginsEngine *engine;
 	GeditApp *app;
 	gboolean restored = FALSE;
-	gchar *dir;
+	const gchar *dir;
 	gchar *icon_dir;
 
 	gedit_debug_message (DEBUG_APP, "Set icon");
 
 	dir = gedit_dirs_get_gedit_data_dir ();
 	icon_dir = g_build_filename (dir, "icons", NULL);
-	g_free (dir);
 
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (), icon_dir);
 	g_free (icon_dir);
@@ -180,8 +178,6 @@ gedit_main (gboolean service)
 	gedit_debug_message (DEBUG_APP, "Init plugins");
 	engine = gedit_plugins_engine_get_default ();
 
-	gtk_about_dialog_set_url_hook (gedit_utils_activate_url, NULL, NULL);
-
 	app = gedit_app_get_default ();
 
 	/* Initialize session management */
@@ -205,6 +201,8 @@ gedit_main (gboolean service)
 	g_object_unref (engine);
 	g_object_unref (app);
 
+	gedit_dirs_shutdown ();
+
 #ifndef ENABLE_GVFS_METADATA
 	gedit_metadata_manager_shutdown ();
 #endif
@@ -213,7 +211,7 @@ gedit_main (gboolean service)
 int
 main (int argc, char *argv[])
 {
-	gchar *dir;
+	const gchar *dir;
 	GeditCommandLine *command_line;
 	gboolean ret;
 	GeditDBus *dbus;
@@ -230,19 +228,17 @@ main (int argc, char *argv[])
 	gedit_debug_init ();
 	gedit_debug_message (DEBUG_APP, "Startup");
 
-	/* FIXME: Remove when gconf not needed anymore */
-	g_setenv ("GSETTINGS_BACKEND", "gconf", FALSE);
-
 	/* Setup locale/gettext */
 	setlocale (LC_ALL, "");
 
 	dir = gedit_dirs_get_gedit_locale_dir ();
 	bindtextdomain (GETTEXT_PACKAGE, dir);
-	g_free (dir);
 
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+	gedit_dirs_init ();
+
 	/* Parse command line arguments */
 	command_line = gedit_command_line_get_default ();
 
